@@ -3,7 +3,7 @@ package Test::Myriad;
 use strict;
 use warnings;
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 use IO::Async::Loop;
@@ -32,6 +32,14 @@ Myriad::Test - a collection of helpers to test microservices.
 
 =head1 DESCRIPTION
 
+A mini utility to help developers testing myriad services.
+
+it can create completely fake services or mock already
+existing ones.
+
+It uses the L<Myriad::Transport::Memory> by default to change that
+you can set the environment variable MYRIAD_TEST_TRANSPORT
+
 =head1 Methods
 
 =head2 add_service
@@ -56,7 +64,7 @@ sub add_service {
     my ($pkg, $meta);
     if (my $service = delete $args{service}) {
         $pkg = $service;
-        $meta = Object::Pad::MOP::Class->for_class(ref $service);
+        $meta = Object::Pad::MOP::Class->for_class($service);
     } elsif ($service = delete $args{name}) {
         die 'The name should look like a Perl package name' unless $service =~ /::/;
         $pkg  = $service;
@@ -76,9 +84,23 @@ sub add_service {
     return Test::Myriad::Service->new(meta => $meta, pkg => $pkg, myriad => $myriad);
 }
 
+=head2 ready
+
+Returns a L<Future> indicate that test env
+is ready to be used.
+
+at the moment it is just a shortcut for L<Myriad> run_future.
+
+=cut
+
+sub ready {
+    return $myriad->run_future;
+}
+
 sub import {
+    my $self = shift;;
     Check::UnitCheck::unitcheckify(sub {
-        $myriad->configure_from_argv()->get();
+        $myriad->configure_from_argv(('--transport', $ENV{MYRIAD_TEST_TRANSPORT} // 'memory', 'service'))->get();
         $loop->later(sub {
             (fmap0 {
                 $myriad->add_service($_);
