@@ -3,7 +3,7 @@ package Test::Myriad::Service;
 use strict;
 use warnings;
 
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
 use Scalar::Util qw(weaken);
@@ -55,7 +55,8 @@ BUILD (%args) {
                         return delete $mocked_rpc->{$method};
                     }
                     try {
-                        await $default_rpc->{$method}->(@_);
+                        my $self = shift;
+                        await $self->$method(@_);
                     } catch ($e) {
                         $log->tracef("An exception has been thrown while calling the original sub - %s", $e);
                         die $e;
